<?php
/** Votic (Vaďďa)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author 2Q
 * @author Aig mest ei varasta
 * @author Andrijko Z.
 * @author Comp1089
 * @author Erdemaslancan
 * @author Paivud
 * @author Trần Nguyễn Minh Huy
 */

$fallback = 'fi';

$messages = array(
# User preference toggles
'tog-underline' => 'Link underlining',

'underline-always' => 'Alõzii',
'underline-never' => 'Eb kõzniid',

# Dates
'sunday' => 'Nätilpäivä',
'monday' => 'Esmezarci',
'tuesday' => 'Tõizarci',
'wednesday' => 'Kõlmõzpäivä',
'thursday' => 'Nelläzpäivä',
'friday' => 'Viďďezpäivä',
'saturday' => 'Laukopäivä',
'sun' => 'Nät',
'mon' => 'Esm',
'tue' => 'Tõi',
'wed' => 'Kõl',
'thu' => 'Nel',
'fri' => 'Viď',
'sat' => 'Lau',
'january' => 'janvaari',
'february' => 'fevraaľi',
'march' => 'martti',
'april' => 'aprilli',
'may_long' => 'mai',
'june' => 'juńi',
'july' => 'juľi',
'august' => 'augusti',
'september' => 'senťaabri',
'october' => 'okťaabri',
'november' => 'nojaabri',
'december' => 'dekaabri',
'january-gen' => 'janvaarii',
'february-gen' => 'fevraalii',
'march-gen' => 'martii',
'april-gen' => 'aprillii',
'may-gen' => 'maja',
'june-gen' => 'junii',
'july-gen' => 'juľii',
'august-gen' => 'augustii',
'september-gen' => 'senťaabrii',
'october-gen' => 'okťaabrii',
'november-gen' => 'nojaabrii',
'december-gen' => 'dekaabrii',
'jan' => 'janvaari',
'feb' => 'fevraali',
'mar' => 'martti',
'apr' => 'aprilli',
'may' => 'mai',
'jun' => 'juni',
'jul' => 'juľi',
'aug' => 'augusti',
'sep' => 'senťaabri',
'oct' => 'okťaabri',
'nov' => 'nojaabri',
'dec' => 'dekaabri',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Gruppa|Gruppad}}',
'category_header' => 'Cuľľed, kummad õvad gruppaz "$1"',
'subcategories' => 'Alagruppad',
'category-media-header' => 'Mediafailid, kummad õvad gruppaz "$1"',
'category-empty' => "''Kase gruppa on tühjä.''",
'hidden-categories' => '{{PLURAL:$1|Salautõttu gruppa|Salautõtud gruppad}}',
'category-subcat-count' => '{{PLURAL:$2|Senez gruppaz on ainult vahtiaava alagruppa.|{{PLURAL:$1|Vahtiaava alagruppa kuulub|Vahtiaava $1 alagruppaa kuuluvad}} sihee gruppaa. Alagruppaďďe cisla gruppaza on $2.}}',
'category-article-count' => '{{PLURAL:$2|Senez gruppaz on ainult vahtiaava cülci.|{{PLURAL:$1|Vahtiaava alagruppa kuulub|Vahtiaava $1 cülciä kuuluvad}} sihee gruppaa. Cülcije cisla gruppaza on $2.}}',
'category-file-count' => '{{PLURAL:$2|Senez gruppaz on ainult vahtiaava faili.|{{PLURAL:$1|Vahtiaava alagruppa kuulub|Vahtiaava $1 failid kuuluvad}} sihee gruppaa. Cülcije cisla gruppaza on $2.}}',
'listingcontinuesabbrev' => 'ladvaub',
'noindex-category' => 'Ebäindekseeritettäväd lehocülled',

'about' => 'Täätühsed',
'newwindow' => '(avaub uuvvõza akkunaza)',
'cancel' => 'Otmeńoit',
'mypage' => 'Minu cülci',
'mytalk' => 'Minu juttu',
'navigation' => 'Valittsõmin',
'and' => '&#32;ja',

# Cologne Blue skin
'qbfind' => 'Etsi',
'qbedit' => 'Muuttaa',
'qbpageoptions' => 'Kase cülci',
'qbspecialpages' => 'Osoobenoid cüľľed',
'faq' => 'FAQ',
'faqpage' => 'Project:FAQ',

# Vector skin
'vector-action-addsection' => 'Vassõn teema',
'vector-action-delete' => 'Pühi',
'vector-action-move' => 'Liikut',
'vector-action-protect' => 'Varjaa',
'vector-view-create' => 'Loo cülci',
'vector-view-edit' => 'Muuttaa',
'vector-view-history' => 'Istori',
'vector-view-view' => 'Lukõa',
'vector-view-viewsource' => 'Lähtekoodi',
'actions' => 'Tekod',
'namespaces' => 'Nimiruumid',
'variants' => 'Variandid',

'errorpagetitle' => 'Vika',
'returnto' => 'Mee takaz cüľľelle $1.',
'tagline' => 'Lähe: {{SITENAME}}',
'help' => 'Api',
'search' => 'Ettsü',
'searchbutton' => 'Etsi',
'go' => 'Mee',
'searcharticle' => 'Mee',
'history' => 'Cüľľee istori',
'history_short' => 'Istori',
'printableversion' => 'Pecatoittõva verzija',
'permalink' => 'Postojannoi linkki',
'view' => 'Prestavleńńõd',
'edit' => 'Muuttaa',
'create' => 'Loo cülci',
'editthispage' => 'Muutu sitä cülciä',
'delete' => 'Pühi',
'deletethispage' => 'Pühi kase cülci',
'protect' => 'Varjaa',
'protect_change' => 'muutu',
'newpage' => 'Uusi cülci',
'talkpage' => 'Juttu senessä cüľľessä',
'talkpagelinktext' => 'Juttu',
'specialpage' => 'Osoobennoi cülci',
'personaltools' => 'Õmad tööriisõd',
'talk' => 'Juttu',
'views' => 'Prestavleńńõd',
'toolbox' => 'Tööriisõd',
'otherlanguages' => 'Muilla ceelillä',
'redirectedfrom' => '(Mešaitõttu cüľľeltä $1)',
'redirectpagesub' => 'Mešaituzcülci',
'lastmodifiedat' => 'Viimõin muutuz: $2 $1',
'jumpto' => 'Hüppä:',
'jumptonavigation' => 'valittsõmisiisõ',
'jumptosearch' => 'ettsüse',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => 'Tääteja {{GRAMMAR:elative|{{SITENAME}}}}',
'aboutpage' => 'Project:Täätühsed',
'copyright' => 'Sisälto on $1 litsentsii mukka svobodnoi.',
'copyrightpage' => '{{ns:project}}:Kopiraitti',
'currentevents' => 'Nücüizõd noovosťi',
'currentevents-url' => 'Project:Nücüizõd noovosťi',
'disclaimers' => 'Ceeltümin vassamizõõ',
'disclaimerpage' => 'Project:Ceeltümin vassamizõõ',
'edithelp' => 'Muutuzavid',
'helppage' => 'Help:Sisälto',
'mainpage' => 'Esicülci',
'mainpage-description' => 'Esicülci',
'portal' => 'Foorum',
'portal-url' => 'Project:Foorum',
'privacy' => 'Salaštrahuituz',
'privacypage' => 'Project:Salaštrahuituz',

'badaccess' => 'Lupa ceeltistü',

'ok' => 'OK',
'retrievedfrom' => 'Jälcinnü adresissa "$1"',
'youhavenewmessages' => 'Teill on $1 ($2).',
'newmessageslink' => 'Uusiit zapiskoit',
'newmessagesdifflink' => 'viimõin muutuz',
'editsection' => 'muuttaa',
'editold' => 'muuttaa',
'viewsourceold' => 'lähtekoodi',
'editlink' => 'muuttaa',
'viewsourcelink' => 'lähtekoodi',
'editsectionhint' => 'Muutta alajakkoa $1',
'toc' => 'Sisälto',
'showtoc' => 'näüt väľľää',
'hidetoc' => 'salauta',
'site-rss-feed' => '$1-RSS-söötte',
'site-atom-feed' => '$1-Atom-söötte',
'page-rss-feed' => '"$1" RSS-söötte',
'page-atom-feed' => '"$1" Atom-söötte',
'red-link-title' => '$1 (cülciä ebõõ)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Artikkeli',
'nstab-user' => 'Cäüttijäcülci',
'nstab-media' => 'Media-cülci',
'nstab-special' => 'Osoobennoi cülci',
'nstab-project' => 'Projekticülci',
'nstab-image' => 'Faili',
'nstab-mediawiki' => 'Ilmottamin',
'nstab-template' => 'Šablooni',
'nstab-category' => 'Gruppa',

# General errors
'error' => 'Vika',
'missing-article' => 'Cüľľee sisältoa eb löütännü täätöbaazassa: $1 $2.

Ussassi se johtub ustaŕeloi sravńoi- vai istorilinkissä roocittulõõ cüľľelee.

Kui cüsümüssessä ebõõ roocittu cülci, võib õlla õlõttõ löütännü ošipkaa sistemalla. Õõ nii üvä ilmuttõma cüľľee adressia vikii [[Special:ListUsers/sysop|praviťeľalõõ]].',
'missingarticle-rev' => '(verzija: $1)',
'badtitle' => 'Paha zagolofkka',
'badtitletext' => 'Cüzüttü artikkelizagolofkka õli vilpilliin, tühjä vai väärii linkitettü ceelijeväliin vai vikiiväliin linkki.',
'viewsource' => 'Lähtekoodi',

# Login and logout pages
'yourname' => 'Cäüttijänimi:',
'yourpassword' => 'Salasõna',
'yourpasswordagain' => 'Tõissaga salain-sõna:',
'remembermypassword' => 'Mäleht minuu (enintään $1 {{PLURAL:$1|päivä|päivää}})',
'login' => 'Cirjut süäme',
'nav-login-createaccount' => 'Cirjut süäme vai registriiroit cäüttijässi',
'loginprompt' => 'Tüü piättä «cookies» võttamin luvata, štobõ entä sisteema ete esitellä.',
'userlogin' => 'Cirjut süäme',
'userloginnocreate' => 'Cirjut süäme',
'logout' => 'Cirjut uloz',
'userlogout' => 'Cirjut uloz',
'nologin' => "Kui Teille veel ebõõ cäüttijänimi, '''$1'''.",
'nologinlink' => 'võitta loovva luguu',
'createaccount' => 'Uusi cäüttijää',
'gotaccount' => 'Tüü õõttõ jo registreerittu? $1.',
'gotaccountlink' => 'Cirjut süäme',
'userlogin-resetlink' => 'Vai unõhtittõ õma loginass?',
'createaccountreason' => 'Süü:',
'mailmypassword' => 'Lähet uusi salasõna elektropoštiikaa',
'loginlanguagelabel' => 'Ceeli: $1',

# Change password dialog
'resetpass-submit-cancel' => 'Otmeńoit',

# Special:PasswordReset
'passwordreset-username' => 'Cäüttijänimi:',

# Special:ChangeEmail
'changeemail-newemail' => 'Vassõn e-mail:',
'changeemail-cancel' => 'Otmeńoit',

# Edit page toolbar
'bold_sample' => 'Pimmiä teksti',
'bold_tip' => 'Pimmiä teksti',
'italic_sample' => 'Kursiivoi teksti',
'italic_tip' => 'Kursiivi',
'link_sample' => 'Linkki',
'link_tip' => 'Sisipooliin linkki',
'extlink_sample' => 'http://www.example.com linki nimi',
'extlink_tip' => 'Eräpooliin linkki (mäleht http:// prefiksi)',
'headline_sample' => 'Zagolofkka-teksti',
'headline_tip' => 'Zagolofkka',
'nowiki_sample' => 'Lissä formattimatoo teksti tänne',
'nowiki_tip' => 'Ignoriiroit viki formatti',
'image_tip' => 'Kuva',
'media_tip' => 'Faililinkki',
'sig_tip' => 'Alacirjutuz aikamerkikaa',
'hr_tip' => 'Gorizontalnoi viiru',

# Edit pages
'summary' => 'Turvotuz:',
'subject' => 'Teema:',
'minoredit' => 'Kase on peeni muutuz',
'watchthis' => 'Lissä kattsõspiiskaa',
'savearticle' => 'Salvo cülci',
'preview' => 'Prestavleńńa',
'showpreview' => 'Näüt prestavleńńa',
'showdiff' => 'Näüt muutussõd',
'anoneditwarning' => 'Että õlõ süämme cirjutõnnu. Teďďee IP-adressi cirjuttanes sene cüľľee muutuzistorisõ.',
'summary-preview' => 'Turvotuhsõ prestavleńńa',
'loginreqlink' => 'cirjut süäme',
'newarticle' => '(Uusi)',
'newarticletext' => 'Sitä cülciä veel ebõõ.
Võitta loovva cüľľee cirjuttamall alla õlõvasõõ tilaa. Kui että taho loovva [[{{MediaWiki:Helppage}}|cülciä]], menka takaz Web-brauzeraa "back"-napuukaa.',
'noarticletext' => '{{GRAMMAR:inessive|{{SITENAME}}}} ebõõ sene nimissä cülciä.
* Võid [[Special:Search/{{PAGENAME}}|ettsiä cüľľee nimellä]] muilta cüľľeltä.
* Võid cirjuttõma uuvvõõ cüľľee <span class="plainlinks">[{{fullurl:{{FULLPAGENAME}}|action=edit}} {{PAGENAME}}]</span>.',
'noarticletext-nopermission' => 'Paraika kazell lehocüllell eb õõ teksta.
Tüü võittõ [[Special:Search/{{PAGENAME}}|kaze nime nimettamizõ löütä]] muiss artikkeliiss, ehci <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}}löütä azjakõhaizõd cirjauhsõd žurnaaliiss]</span>.',
'previewnote' => "'''Kase on ainult prestavleńńa.''' Cülciä ebõõ veel salvotõttu!",
'editing' => 'Muutun $1',
'editingsection' => 'Muuttõmizõll on õsa cüľľess $1',
'copyrightwarning' => "Kõik {{SITENAME}}'lle formittu saacid katsotaa julkaistussi $2 -litsentsi mukka ($1). Kui että taho, jot Teďďee cirjutussa muutõtaa armõttomassi ja svobodno cävvää uuvvõllõõ, elä cirjuttõga.<br />Toož, Te luppattõ, jot cirjutittä Teďďee teksti ize, vai kopiiroizitta slobodnoissa cüľľessä.<br />'''ELÄ CÄÜTTEGA TECEJÄÕIKUSÕKAA OĎĎÕLTUIT MAŤERIIT ILMA LUPPA!'''",
'templatesused' => 'Sell cüľľell {{PLURAL:$1|cäütetüd šabloonid}}:',
'templatesusedpreview' => '{{PLURAL:$1|Šabloonid}} sellä prestavleńńalla:',
'template-protected' => '(oďďõttu)',
'template-semiprotected' => '(varjõttu anonüümeilt ja uusilt cäüttijilt)',
'hiddencategories' => 'Kase cülci kuulub {{PLURAL:$1|vahtiaavaa salautõttuu gruppaa|vahtiaavii salautõttuisõõ gruppoisõõ}}:',
'permissionserrorstext-withaction' => 'Teill ebõõ luppa $2 {{PLURAL:$1|vahtiaavass süüss|vahtiaaviss süiss}} peräss:',
'recreate-moveddeleted-warn' => "'''Tähele-pano. Tüü loottõ taaz lehocülce, kumpa õli eespäi poisõttu.'''

Tarkassaga, vai tarviz teile sitä tehä. Alapallõ õlla kaze lehocülle poissamizije ja nimije muuttamizije žurnaalad esitettü.",
'moveddeleted-notice' => "Kase cülci on pühittü. Alla on sene cüľľee pühi'istori.",

# Parser/template warnings
'post-expand-template-inclusion-warning' => "'''Etetäätämin:''' lizettävije šabloonije summaarin koko on liiga suuri.
Mõnõd šabloonad eväd lee lizettü.",
'post-expand-template-inclusion-category' => 'Lehocülled, jõgõit vart lizettävije šabloonije sallittu koko on ületettü',
'post-expand-template-argument-warning' => "'''Tähele-pano''': kase lehocülci sisältäb vähepält ühs šabloona, kumma argumental on liiga suuri avvamizõ koko. Mokomad argumentad eväd õltu näütettü",
'post-expand-template-argument-category' => 'Lehocülled, jõgad sisälletä väl’l’ä-jätettü šabloonije argumentad.',

# History pages
'viewpagelogs' => 'Näüt sene cüľľee logid',
'currentrev' => 'Nücüin verzija',
'currentrev-asof' => 'Nücüin verzija $1',
'revisionasof' => 'Verzija $1',
'revision-info' => '41. Verssija $1-ss; $2',
'previousrevision' => '← Vanõpi verzija',
'nextrevision' => 'Uuvvõpi verzija →',
'currentrevisionlink' => 'Nücüin verzija',
'cur' => 'nüc.',
'last' => 'entin',
'histlegend' => "Merkid: ({{int:cur}}) = vahõ nütšüizese verzijaa, ({{int:last}}) = vahõ entiizese verzijaa, '''{{int:minoreditletter}}''' = peeni muutuz",
'history-fieldset-title' => 'Ľistvoit muutuzistoria',
'history-show-deleted' => "Tol'ko poisõttu",
'histfirst' => 'Kõikkõa varaizõpid',
'histlast' => 'Kõikkõa viimõizõpid',

# Revision feed
'history-feed-item-nocomment' => '$1 .. $2',

# Revision deletion
'rev-delundel' => 'näüt/salauta',
'rev-showdeleted' => 'näüt väľľää',
'revdelete-show-file-submit' => 'Daa',
'revdelete-radio-set' => 'Daa',
'revdelete-radio-unset' => 'Eb',
'revdelete-log' => 'Süü:',
'revdel-restore' => 'muutu näcüvüss',
'revdel-restore-deleted' => 'poizõttu verssijad',
'revdel-restore-visible' => 'nähtäväd verssijad',
'pagehist' => 'Cüľľee istori',
'revdelete-reasonotherlist' => 'Muu süü',

# History merging
'mergehistory-reason' => 'Süü:',

# Merge log
'revertmerge' => 'Kummut ühesüz',

# Diffs
'history-title' => 'Cüľľee $1 muutuzistori',
'lineno' => 'Viiru $1:',
'compareselectedversions' => 'Võrrõõ valitsõttuit verzijoit',
'editundo' => 'kummut',
'diff-multi' => 'Eb õõ näütettü {{PLURAL:$1|õsa-võttaja|õsa-võttajije}} {{PLURAL:$2|$2 väli-verssija $1|väli-verssijad $1}}',

# Search results
'searchresults' => 'Etsüü tulõmuhsõd',
'searchresults-title' => 'Etsü tulõmuhsõd ettsüsõnalõõ "$1"',
'searchresulttext' => 'Lisäsoobšeńńad ettsimizessä on [[{{MediaWiki:Helppage}}|praavilacüľľellä]].',
'searchsubtitle' => 'Etsizid fraaza \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|kõikõd cüľľed, kummad alkõa fraazaakaa "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|kõikõd cüľľed näütteväd cüľľelee "$1"]])',
'searchsubtitleinvalid' => "Ettsizittä: '''$1'''",
'notitlematches' => 'Eb löütännü miltäiss cülciä sene ettsüsõnaaka',
'notextmatches' => 'Ettsisõnaa eb löütünnü cüľľee tekstiissä',
'prevn' => '{{PLURAL:$1|edellinen|$1 entiiss}}',
'nextn' => '{{PLURAL:$1|$1}} vahtiaava →',
'prevn-title' => '{{PLURAL:$1|Eellin cirjauz|$1 eellissa cirjaussa}}',
'nextn-title' => '{{PLURAL:$1|Sõurava cirjauz|$1 sõurava cirjaussa}}',
'shown-title' => 'Näüttä $1 {{PLURAL:$1|cirjauz|cirjaussa}} lehocüllell',
'viewprevnext' => 'Näüt ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-exists' => 'Kazez viki-projeektaz on lehocülci «[[:$1]]» õõmaz',
'searchmenu-new' => 'Tehä lehocülci «[[:$1]]» senez viki-projeektaz!',
'searchprofile-articles' => 'Pääcülcid',
'searchprofile-project' => 'Selvitühse ja projeekta lehocülled',
'searchprofile-images' => 'Multimedia',
'searchprofile-everything' => 'Kõik',
'searchprofile-advanced' => 'Lizätez',
'searchprofile-articles-tooltip' => 'Etsi "$1":az',
'searchprofile-project-tooltip' => 'Etsi "$1":az',
'searchprofile-images-tooltip' => 'Failõje õttsigo',
'searchprofile-everything-tooltip' => 'Õttsigo kõikill lehocüllill (ceskussõõmizõ lehocülled siällhulgaz)',
'searchprofile-advanced-tooltip' => 'Annõttu nimije tiloiz õttsia',
'search-result-size' => '$1 ({{PLURAL:$2|1 sõna|$2 sõna}})',
'search-result-category-size' => '$1 {{PLURAL:$1|jäse|$1 jäsentä}} ({{PLURAL:$2|1 all-kategoorija|$2 all-kategoorijad}}, {{PLURAL:$3|1 faili|$3 faila}})',
'search-redirect' => '(mešaituz $1)',
'search-section' => '(alajako $1)',
'search-suggest' => 'Tähetidko: $1',
'search-interwiki-caption' => 'Sõzarprojektid',
'search-interwiki-default' => 'tulõmuhsõd $1:',
'search-interwiki-more' => '(lisä)',
'searchrelated' => 'sittu',
'searchall' => 'kõik',
'showingresultsheader' => "{{PLURAL:$5|Tuloz '''$1''' '''$3'''-ss|Tulohsõd '''$1-$2''' '''$3'''-ss}} «$4» vart",
'nonefound' => "'''Zametšańńa''': Ettsü etsib anult osiss nimiruumii.
Proovvi lizät etsün alkuu ''all:'', nii ettsü etsib kõikkõõ sisältoo (taas juttucüľľeekaa, sablooniikaa, jne.), vai tarvittõga nimiruumi niku prefiksi.",
'search-nonefound' => 'Cüsümühse mukaizõssi eb õõ mitäid löütettü.',
'powersearch' => 'Etenennü ettsü',
'powersearch-legend' => 'Etenennü ettsü',
'powersearch-ns' => 'Etsi nimiruumõssa:',
'powersearch-redir' => 'Spiiska mešaitussijõ',
'powersearch-field' => 'Etsi',

# Preferences page
'preferences' => 'Koozid',
'mypreferences' => 'Minu koozid',
'skin-preview' => 'Prestavleńńa',
'prefs-datetime' => 'Kuupäivä i aika',
'prefs-user-pages' => 'Cäüttijäcülcid',
'prefs-rc' => 'Viimõizõd muutussõd',
'searchresultshead' => 'Etsi',
'timezoneregion-africa' => 'Afrikka',
'timezoneregion-america' => 'Ameerika',
'timezoneregion-asia' => 'Aazija',
'timezoneregion-australia' => 'Avstraaľija',
'timezoneregion-europe' => 'Evrooppaa',
'prefs-files' => 'Failid',
'youremail' => 'E-mail:',
'username' => 'Cäüttijänimi:',
'yourrealname' => 'Minu nimi:',
'yourlanguage' => 'Ceeli:',
'yourgender' => 'Sukupooli',
'gender-male' => 'Mehin',
'gender-female' => 'Naisin',
'email' => 'E-mail',
'prefs-help-email' => 'E-mail eb õõ pakollin, ain se leeb vajallin, kui tüü unõhtattõ salain-sõnass.',
'prefs-help-email-others' => 'Se lupabci muilõ õsa-võttajilõ võtta ühteüttä tejjeka tejje personaaliss lehocülless viittau kautta, ilma tejje e-mail’a tääotusõ vajaussa.',

# User rights
'userrights-reason' => 'Süü:',

# Groups
'group-user' => 'Сäüttijäd',
'group-sysop' => 'Praviťeľad',
'group-all' => '(kõik)',

'group-user-member' => 'cäüttijä',

'grouppage-user' => '{{ns:project}}:Сäüttijäd',
'grouppage-sysop' => '{{ns:project}}:Praviťeľad',

# Special:Log/newusers
'newuserlogpage' => 'Uuvvõd cäüttijäd',

# User rights log
'rightslog' => 'Cäütteminõikuslogi',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'muutu sitä cülciä',

# Recent changes
'nchanges' => '$1 {{PLURAL:$1|muutuz|muutussõd}}',
'recentchanges' => 'Viimõizõd muutussõd',
'recentchanges-legend' => 'Viimass muutuhsõss valimizõd',
'recentchanges-feed-description' => 'Sell sivull võib vahtia uutizijõ muutuhsiit.',
'recentchanges-label-newpage' => 'Kaze kirjauhsõka õli muu lehocülci lootu.',
'recentchanges-label-minor' => 'Kase on peeni muutuz',
'recentchanges-label-bot' => 'Kase kõrjauz on robotaka lootu',
'recentchanges-label-unpatrolled' => 'Kasta kõrjaussa eb tarkisõtti veel',
'rcnote' => 'Alla on {{PLURAL:$1|ühsi muutuz|viimeiziit $1 muutussiit}} viimeize {{PLURAL:$2|ühee päivää|$2 päivää}}, $4 $5.',
'rcnotefrom' => 'Alapallõ õlla lugõtõltu muuttamizõd $2-lt ($1-lõssaa)',
'rclistfrom' => 'Näüt uuvvõd muutuhsõd $1 alguss',
'rcshowhideminor' => '$1 peened muutussõd',
'rcshowhidebots' => '$1 botid',
'rcshowhideliu' => '$1 süäme cirjutõnnud cäüttijäd',
'rcshowhideanons' => '$1 anonüümid cäüttijäd',
'rcshowhidepatr' => 'Tarkasõttu kõrjausije $1',
'rcshowhidemine' => '$1 õmad muutussõd',
'rclinks' => 'Näüt viimõiss $1 muutuhsõiss viimõizõ $2 päivää ajalt.<br />$3',
'diff' => 'vahõ',
'hist' => 'istori',
'hide' => 'Salauta',
'show' => 'Näüt väľľää',
'minoreditletter' => 'p',
'newpageletter' => 'U',
'boteditletter' => 'b',
'rc-enhanced-expand' => 'Näüt detaaľiit (JavaScript on tarviz)',
'rc-enhanced-hide' => 'Salauta detaaľiit',

# Recent changes linked
'recentchangeslinked' => 'Sukulaizõd muutussõd.',
'recentchangeslinked-feed' => 'Sukulaizõd muutussõd',
'recentchangeslinked-toolbox' => 'Sukulaizõd muutussõd',
'recentchangeslinked-title' => 'Cüľľelt $1 linkitettüďďe cülcije muutuhsõd.',
'recentchangeslinked-summary' => "Kase osoobennoi cülci näütteb muutusõd cülcillä, kummalõõ on seltä cüľľeltä näüteltü.
Cüľľed, kummad õmad teďďellä [[Special:Watchlist|kattsõspiizgalla]] on cirjuttõnnu '''pimmiässi'''.",
'recentchangeslinked-page' => 'Cüľľee nimi:',
'recentchangeslinked-to' => 'Näüt muutuhsõd cülciisee, kummall on linkki annõttuu cülcesee',

# Upload
'upload' => 'Laajõngoit failia ülez',
'uploadbtn' => 'Laajõngoit failia ülez',
'uploadlogpage' => 'Faililogi',
'filename' => 'Failinimi',
'filedesc' => 'Turvotuz',
'fileuploadsummary' => 'Turvotuz:',
'uploadedimage' => '"[[$1]]" on laajõngoitõttu ülez',

'license' => 'Litseenttsija:',
'license-header' => 'Litseenttsija',

# Special:ListFiles
'imgfile' => 'faili',
'listfiles_thumb' => 'Peenikuva',
'listfiles_date' => 'Kuupäivä',
'listfiles_name' => 'Nimi',
'listfiles_user' => 'Сäüttijä',

# File description page
'file-anchor-link' => 'Faili',
'filehist' => 'Failii istori',
'filehist-help' => 'Šcolkoittõga Päiväcisla/Celloaika näe miltäin faili õli sell aiga pilkall.',
'filehist-deleteone' => 'pühi',
'filehist-revert' => 'kummut',
'filehist-current' => 'nücüin',
'filehist-datetime' => 'Päiväсisla/Сelloaika',
'filehist-thumb' => 'Peenikuva',
'filehist-thumbtext' => 'Peenikuva $1 verzijalõõ',
'filehist-user' => 'Сäüttijä',
'filehist-dimensions' => 'Mitad',
'filehist-comment' => 'Zametšańńa',
'imagelinks' => 'Faililinkid',
'linkstoimage' => 'Selle kuvallõ {{PLURAL:$1|näütteeb kase сülсi|näütteväd kaned сüľľed}}:',
'nolinkstoimage' => 'Eb ühelläid lehocüllell cäütetä kase faila.',
'sharedupload' => 'Kase faili on $1:lt ja muud projektõd saavad cäüttää sitä.',
'sharedupload-desc-here' => 'Se fajla on $1-ss ja võib muiz projeektiz õlla cäütettävänä.
Seness [$2 kuvauhsõ lehocülless] informaattsija on alapallõ annõttu.',
'uploadnewversion-linktext' => 'Laajõngoit uusi verzija seness failiss ülez',

# File reversion
'filerevert-comment' => 'Süü:',
'filerevert-submit' => 'Kummut',

# File deletion
'filedelete-comment' => 'Süü:',
'filedelete-submit' => 'Pühi',

# Random page
'randompage' => 'Satunnain lehocülci',

# Statistics
'statistics' => 'Staťisťikka',
'statistics-pages' => 'Cülcid',

'brokenredirects-edit' => 'muuttaa',
'brokenredirects-delete' => 'pühi',

'withoutinterwiki-submit' => 'Näüt väľľää',

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|baitti|baittia}}',
'nmembers' => '$1 {{PLURAL:$1|selttsilain|selttsilaizõd}}',
'prefixindex' => 'Kõik cüľľed prefiksiikaa',
'usercreated' => '33. $3 on entä cirjannu $1 $2-na',
'newpages' => 'Uuvvõd cüľľed',
'newpages-username' => 'Cäüttijänimi:',
'move' => 'Liikut',
'movethispage' => 'Liikut kase cülci',
'pager-newer-n' => '{{PLURAL:$1|uuvvõpi 1|uuvvõpad $1}}',
'pager-older-n' => '{{PLURAL:$1|vanöpi 1|vanõpad $1}}',

# Book sources
'booksources' => 'Сirjalähed',
'booksources-search-legend' => 'Etsi сirjalähteit',
'booksources-go' => 'Mee',

# Special:Log
'log' => 'Logid',

# Special:AllPages
'allpages' => 'Kõik artikkelid',
'alphaindexline' => '$1 ... $2',
'prevpage' => 'Entin сülсi ($1)',
'allpagesfrom' => 'Сüľľelt',
'allpagesto' => 'Сüľľessaa',
'allarticles' => 'Kõikõd cüľľed',
'allpagessubmit' => 'Mee',

# Special:Categories
'categories' => 'Gruppad',

# Special:DeletedContributions
'sp-deletedcontributions-contribs' => 'Minu avittamizõd',

# Special:LinkSearch
'linksearch' => 'Ulkopoolizõd linkid',
'linksearch-ns' => 'Nimiruumi:',
'linksearch-ok' => 'Etsi',
'linksearch-line' => 'Linki $1-sõ $2-ss',

# Special:ListUsers
'listusers-submit' => 'Näüt väľľää',

# Special:ListGroupRights
'listgrouprights-members' => '(selttsilainspiiska)',

# Email user
'emailuser' => 'Lähettega elektropoštia selle cäüttijälle',
'emailusername' => 'Cäüttijänimi:',
'emailmessage' => 'Ilmottamin:',

# Watchlist
'watchlist' => 'Kattsõspiiska',
'mywatchlist' => 'Minu kattsõspiiska',
'watchlistfor2' => '$2 - $1 vart',
'addedwatchtext' => "Cülci \"[[:\$1]]\" on lisättü Teďďee [[Special:Watchlist|kattsospiizgallõ]].
Cülcese ja sene juttucülcese tehäväd tulõvaizõd muutuhsõd leeväd cisloitõtud siäll.
Cülci leeb cirjutõttu '''pimmiässi''' [[Special:RecentChanges|spiizgall viimeizije muutuhsijõ]].",
'removedwatchtext' => 'Cülci "[[:$1]]" on pantu [[Special:Watchlist|teďďee kattsõspiizgalt]] poiz.',
'watch' => 'Katso',
'watchthispage' => 'Katso sitä cülciä',
'unwatch' => 'Lõpõt kattsõõmin',
'watchlist-details' => 'Kattsõspiizgall on {{PLURAL:$1|$1 cülci|$1 cülciä}} (ilma juttucülciit).',
'wlshowlast' => 'Näüt viimeized $1 tunnia vai $2 päivää $3',
'watchlist-options' => 'Kattsõspiizgaa valimizõd',

# Displayed when you click the "watch" button and it is in the process of watching
'watching' => 'Kattsõõn…',
'unwatching' => 'Kattsõõmizõõ lõpõttõmin…',

# Delete
'deletepage' => 'Pühi cülci',
'delete-legend' => 'Pühi',
'confirmdeletetext' => 'Õlõtta pühcimässä cüľľee vai failii ja kõigõ sene istorii. Õlka nii üvä, kõvissõga jot tahotta sitä tehä, jot saatta arvoa sledstvijäd jot pühcimüz on [[{{MediaWiki:Policy-url}}|poolissaa]] mukka.',
'actioncomplete' => 'Töö tehtü lõppuu',
'actionfailed' => 'Vika',
'deletedtext' => '"$1" on pühittü.
Cüľľellä $2 on spiiska viimeiziss pühcimühsiiss.',
'dellogpage' => 'Pühitüd cüľľed',
'deletecomment' => 'Süü',
'deleteotherreason' => 'Muu vai lisä süü',
'deletereasonotherlist' => 'Muu süü',

# Rollback
'rollback_short' => 'Vääntega',
'rollbacklink' => 'vääntega',

# Protect
'protectlogpage' => 'Varjõtud cüľľed',
'protectedarticle' => '"[[$1]]" on nüd varjõttu',
'modifiedarticleprotection' => 'muuti cüľľee [[$1]] varjauztasoa',
'protectcomment' => 'Süü',
'protectexpiry' => 'Lõpub:',
'protect_expiry_invalid' => 'Lõppuaika eb kõlpa.',
'protect_expiry_old' => 'Lõppuaika on meneväz.',
'protect-text' => "Võitta kattsoa ja muuttaa cüľľee '''$1''' lupoit.",
'protect-locked-access' => "Että või muuttaa cüľľee varjauztasoa. All on cüľľee \"'''\$1'''\" nücüized varjauztazod:",
'protect-cascadeon' => 'Kase cülci on varjõttu, ku on sisällütettü all {{PLURAL:$1|õlõvaa jadgotussi varjõttuhõõ cülcese|õlõvii jadgotussi varjõttuisõ cülciise}}. Võitta muuttaa sene cüľľee varjuztasoa, mutta se eb vaikuta jadgotõttuu varjuhsiise.',
'protect-default' => 'Salli kõik cäüttijäd',
'protect-fallback' => 'Treebuit $1-õikuz',
'protect-level-autoconfirmed' => 'Piättee uuvvõd ja anonüümed cäüttijäd',
'protect-level-sysop' => 'Ainult praviťeľad',
'protect-summary-cascade' => 'jadgotõltu',
'protect-expiring' => 'lõpub $1',
'protect-expiry-indefinite' => 'iciin',
'protect-cascade' => 'Varjaa jõka cülci, kumpa on tänne cülcesee sisällütennü.',
'protect-cantedit' => 'Että või muuttaa cüľľee varjauztasoa, ku tüü että saa muuttaa cülciä.',
'protect-otherreason-op' => 'Muu süü',
'protect-expiry-options' => '1 tunni:1 hour,1 päivä:1 day,1 näteľi:1 week,2 näteľiä:2 weeks,1 kuu:1 month,3 kuut:3 months,6 kuut:6 months,1 voosi:1 year,iciin:infinite',
'restriction-type' => 'Rajauz',
'restriction-level' => 'Varjauz',

# Restrictions (nouns)
'restriction-edit' => 'Muuttaa',
'restriction-move' => 'Liikut',
'restriction-create' => 'Loo cülci',

# Undelete
'undeletelink' => 'näüt/vääntee',
'undeleteviewlink' => 'prestavleńńõd',
'undeletecomment' => 'Süü:',
'undelete-search-submit' => 'Etsi',
'undelete-show-file-submit' => 'Daa',
'undelete-revisionrow' => '$1 $2 ($3) $4 . . $5 $6 $7',

# Namespace form on various pages
'namespace' => 'Nimiruumi:',
'invert' => 'Cäänn nimiruumivalimin päävassaizõssi',
'blanknamespace' => '(Artikkelid)',

# Contributions
'contributions' => '{{GENDER:$1|Cäüttijää}} avittamizõd',
'contributions-title' => 'Cäüttijää $1 avittamizõd',
'mycontris' => 'Minu avittamizõd',
'contribsub2' => 'Cäüttijää $1 ($2) avittamizõd',
'uctop' => '(ülez)',
'month' => 'Kuu',
'year' => 'Voosi:',

'sp-contributions-newbies' => 'Näüt uusijõõ cäüttijee muutuhsõd',
'sp-contributions-blocklog' => 'piättelemized',
'sp-contributions-uploads' => 'lassausõd',
'sp-contributions-logs' => 'logid',
'sp-contributions-talk' => 'Juttu',
'sp-contributions-search' => 'Etsi avittamisiit',
'sp-contributions-username' => 'IP-adressi vai cäüttijänimi',
'sp-contributions-toponly' => 'Viimeized verssijad näüttä',
'sp-contributions-submit' => 'Etsi',

# What links here
'whatlinkshere' => 'Linkid tänne',
'whatlinkshere-title' => 'Cüľľed, kummad näütellä cüľľelle "$1"',
'whatlinkshere-page' => 'Cülci:',
'linkshere' => "Vahtiaavilt cülciilt on linkki cüľľelle '''[[:$1]]''':",
'nolinkshere' => "Mitäid eb viitata '''[[:$1]]-sõ'''",
'isredirect' => 'mešaituzcülci',
'istemplate' => 'sisällütüz šabloonii',
'isimage' => 'kuvalinkki',
'whatlinkshere-prev' => '{{PLURAL:$1|entiin cülci|$1 entiiss cülciä}}',
'whatlinkshere-next' => '{{PLURAL:$1|vahtiaava cülci|$1 vahtiaava cülciä}}',
'whatlinkshere-links' => '← linkid',
'whatlinkshere-hideredirs' => '$1 mešaituhsõd',
'whatlinkshere-hidetrans' => '$1 sisällütühsed',
'whatlinkshere-hidelinks' => '$1 linkid',
'whatlinkshere-hideimages' => '$1 faililinkid',
'whatlinkshere-filters' => 'Fiľtrad',

# Block/unblock
'blockip' => 'Piättee cäüttijää',
'ipbreason' => 'Süü:',
'ipboptions' => '2 tunnia:2 hours,1 päivä:1 day,3 päivää:3 days,1 näteľi:1 week,2 näteľiä:2 weeks,1 kuu:1 month,3 kuut:3 months,6 kuut:6 months,1 voosi:1 year,iciin:infinite',
'ipbotheroption' => 'muu',
'ipblocklist' => 'Piäteltüd IP-adressid ja cäüttijänimed',
'blocklist-reason' => 'Süü',
'ipblocklist-submit' => 'Etsi',
'infiniteblock' => 'iciin',
'blocklink' => 'piättee',
'unblocklink' => 'rooci piäsüss',
'change-blocklink' => 'muutu piätüss',
'contribslink' => 'avittamizõd',
'blocklogpage' => 'Piätüzlogi',
'blocklogentry' => 'piätteli cäüttijää vai IP-cislaa [[$1]]. Piättelemin lõpub $2 $3',
'unblocklogentry' => 'rooci cäüttijält $1 muutuzpiäsüss',
'block-log-flags-nocreate' => 'lukuloomin piäteltü',

# Move page
'movepagetext' => "Alla õlõvall ruumõll võitta anta cüľľelle uutt nimiä; kõik cüľľee istori leeb liikutõttu uuvvõ nimee alle.
Vanass cüľľess nõizõb tulõma mešaituzcülci, kumpa näütteeb uuvvõsõ cülcese.
Võitta obnovoittaa cülcese silmell lüüvvävä mešaituhsõd avtomaattisessi uuvõllõ nimelle.
Kui että taho sitä tehävää avtomaattisessi, mälehtega ettsiää [[Special:DoubleRedirects|kahskõrtaissit]] vai [[Special:BrokenRedirects|katciit]] mešaituhsiit.
Õlõtta vastuussa sihee, jot linkid näütteeväd sinne, kuhõõ ned pitäiziväd näütellää.

Cülciä '''eb''' nõizõ liikuttama, kui uusi nimi on jo cäütennü, muut kuiva kui cülci on tühjä vai on mešaituz, kummall ebõõ muutuzistoria.
See täheteb sitä, jot võitta liikuttaa cüľľee takaz vanalle nimelle kui öhsünettä, mutta että või cirjuttaa eloz õlõvaa cüľľee päälle.

See saattab õlla suuri ja oottõmizõtoi muutuz populaarnoille cüľľelle. Õlka nii üvä, obespecoittõga, jot saatta arvoa sledstvijäd ennee kui liikutta cüľľee.",
'movepagetalktext' => "Cülci ja sene juttucülci leeväd liikutõtud ühez, '''va kui''':
*Tseeľicüľľell on eloz juttucülci, kumpa ebõõ tühjä, vai
*Jätättä all õlõvaa ruuoo merkkittämättä.

Neill kõhtoill piättä liikuttaa vai ühissää cüľľee cäzi.",
'movearticle' => 'Liikut cülci',
'newtitle' => 'Uusi nimi cüľľelee',
'move-watch' => 'Katso sitä cülciä',
'movepagebtn' => 'Liikut cülci',
'pagemovedsub' => 'Liikka tuli valmessi',
'movepage-moved' => '\'\'\'"$1" on liikuttu nimelee "$2"\'\'\'',
'articleexists' => 'Tseeľicülci on jo eloz, vai võõbornoi nimi eb kõlpa. Õlka nii üvä ja valittsõga uusi nimi.',
'talkexists' => "'''Cüľľee liikka tuli valmessi, a jutticülciä eb õli liikutõttu, ku uuvvõ zagolofkaa all on jo juttucülci. Juttucülcije sisälto piättä ühinessä cäzi.'''",
'movedto' => 'liikutõttu',
'movetalk' => 'Liikut toož juttucülci',
'movelogpage' => 'Liikkalogi',
'movereason' => 'Süü',
'revertmove' => 'kummut',

# Export
'export' => 'Cülciďďee väľľää veto',

# Namespace 8 related
'allmessagesname' => 'Nimi',
'allmessagesdefault' => 'Standartin teksta',
'allmessages-language' => 'Ceeli:',
'allmessages-filter-submit' => 'Mee',

# Thumbnails
'thumbnail-more' => 'Suurõt',
'thumbnail_error' => 'Vika: $1',

# Special:Import
'import-upload-filename' => 'Failinimi:',
'import-comment' => 'Zamecańńa:',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Teďďee cäüttijäcülci',
'tooltip-pt-mytalk' => 'Teďďee juttu-cülci',
'tooltip-pt-preferences' => 'Teďďee koozid',
'tooltip-pt-watchlist' => 'Spiiska cülcissä, kummad muutussia kattsõõtta',
'tooltip-pt-mycontris' => 'Spiiska teďďee avittamisiit',
'tooltip-pt-login' => 'Müü taritsõmmõ teit süäme cirjuttõma, a ebõõ tarvitõttõva',
'tooltip-pt-logout' => 'Cirjut uloz',
'tooltip-ca-talk' => 'Juttu sisällossa',
'tooltip-ca-edit' => 'Tüü võittõ muuttaa sitä cülciä.
Õõ nii üvä, ennee salvomiss, retsenziroittiga!',
'tooltip-ca-addsection' => 'Lissä uusi alaõsa',
'tooltip-ca-viewsource' => 'Kase cülci on varjõttu.
Että või muuttaa cülcia, mutta võittõ kattsoa sene lähtekoodi.',
'tooltip-ca-history' => 'Sene cüľľee vanad verzijad',
'tooltip-ca-protect' => 'Varjaa kase cülci',
'tooltip-ca-delete' => 'Pühi kase cülci',
'tooltip-ca-move' => 'Liikut kase cülci',
'tooltip-ca-watch' => 'Lissä kase cülci kattsõspiiskalõõ',
'tooltip-ca-unwatch' => 'Paa kase cülci Teďďee kattsõspiizgalt poiz',
'tooltip-search' => 'Etsi vikissa',
'tooltip-search-go' => 'Mee cüľľelee, kummall on vakurat sesama nimi (kui eloz on)',
'tooltip-search-fulltext' => 'Etsi cülciltä sitä tekstiä',
'tooltip-p-logo' => 'Mee esicüľľelee',
'tooltip-n-mainpage' => 'Mee esicüľľelee',
'tooltip-n-mainpage-description' => 'Mee esicüľľelee',
'tooltip-n-portal' => 'Juttua projektissa: Mitä tüü võittõ tehä, kuza levvette mitä',
'tooltip-n-currentevents' => 'Lugõ soobšeńńad nücüizess kõhtoiss',
'tooltip-n-recentchanges' => 'Spiiska uusissa muutussissa',
'tooltip-n-randompage' => 'Avaa cülcia kõhtõissi',
'tooltip-n-help' => 'Praavila',
'tooltip-t-whatlinkshere' => 'Spiiska kõikkissa cülcissä, kummad tänne näütellä',
'tooltip-t-recentchangeslinked' => 'Viimõizõd muuttussõd cülcillä, kummalõõ on siittä näüteltü',
'tooltip-feed-rss' => 'RSS-söötte selle cüľľelle',
'tooltip-feed-atom' => 'Atom-söötte selle cüľľelle',
'tooltip-t-contributions' => 'Näüt spiiska sene cäüttijää avittamiss',
'tooltip-t-emailuser' => 'Lähettega elektropoštia selle cäüttijälle',
'tooltip-t-upload' => 'Laajõngoit failia ülez',
'tooltip-t-specialpages' => 'Spiiska kõikkissa osoobenoissa cülcissä',
'tooltip-t-print' => 'Sene cüľľee pecatoittõva verzija',
'tooltip-t-permalink' => 'Postojannoi linkki cüľľee selle verzijalõõ',
'tooltip-ca-nstab-main' => 'Näüt artikkelia',
'tooltip-ca-nstab-user' => 'Näüt cäüttijäcülci',
'tooltip-ca-nstab-special' => 'Kase on osoobennoi cülci, tüü ed saa sitä muuttõma',
'tooltip-ca-nstab-project' => 'Näüt projekticülci',
'tooltip-ca-nstab-image' => 'Näüt failicülci',
'tooltip-ca-nstab-template' => 'Näüt šablooni',
'tooltip-ca-nstab-category' => 'Näüt gruppacülci',
'tooltip-minoredit' => 'Merkit kase peenessi muutuhsõssi',
'tooltip-save' => 'Salvo muutussõd',
'tooltip-preview' => 'Retsenziroitta muutuss. Õõ nii üvä, ennee salvomiss, retsenziroittiga!',
'tooltip-diff' => 'Näüt tehtüd muutuhsõd',
'tooltip-compareselectedversions' => 'Näütää vahõd 2 valitsõttuďďõ verzijoďďõ väliz',
'tooltip-watch' => 'Lissä kase cülci kattsõspiizgallõ',
'tooltip-rollback' => 'Vääntega cüľľee teksti vanõmpi verzijalõõ',
'tooltip-undo' => '"Kummut" väänteeb kasene muutusõõ ja avab artikkelii prestavleńńaa.
Toož, võittõ tširjutta väänteüssee süü.',
'tooltip-summary' => 'Turvotuz',

# Browsing diffs
'previousdiff' => '← Vanõpi muutuz',
'nextdiff' => 'Uuvvõpi muutuz →',

# Media information
'file-info-size' => '$1 × $2 px, $3, MIME-sortta: $4',
'file-nohires' => 'Suurõpaa kuva ebõõ.',
'svg-long-desc' => 'SVG-faili $1 × $2 px, failii suuruz: $3',
'show-big-image' => 'Kõrka-rezoľuuttsiin verzija',

# Special:NewFiles
'ilsubmit' => 'Etsi',

# Bad image list
'bad_image_list' => 'Spiizgaa formatti on:

Ainult viirud, kummad alkõa merkiigaa * leeväd pantu panõlõõ.
Esimein linkki viirulla piäb õllaa linkki kahõpäälizõlõõ faililõõ.
Kõik muud linkid leeväd pantu panõlõõ nii ku ero.',

# Metadata
'metadata' => 'Sisältokuvõtuz',
'metadata-help' => 'Kase faili sisältäb lisäinformatsijaa, mikä on lizättü tsifrovoi kamera vai skanera poolt.
Kui faili on muutõttu, siiz detaaľid võivad õlla kahõllaizõd muutõtull failill.',
'metadata-expand' => 'Näüt lontsõkait detaaľiit',
'metadata-collapse' => 'Salauta lontsõkait detaaľiit',
'metadata-fields' => 'Vahtiaavad platsid õvad vällez kuvacüľľell, ku sisältotabľittsa on peenettettü.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# Exif tags
'exif-gpstimestamp' => 'GPS-aika',
'exif-languagecode' => 'Ceeli',
'exif-iimcategory' => 'Gruppa',

'exif-meteringmode-255' => 'Muu',

'exif-gaincontrol-0' => 'Eb õõ',

'exif-iimcategory-ace' => 'Kunsti ja kulttuuri',
'exif-iimcategory-hth' => 'Terveüz',
'exif-iimcategory-pol' => 'Politiikka',
'exif-iimcategory-wea' => 'Ilma',

# External editor support
'edit-externally' => 'Muuttaa sitä failia ulkopoolizõõ prograammiikaa.',
'edit-externally-help' => '(Kattsoga [//www.mediawiki.org/wiki/Manual:External_editors praavilõd], kui tahotta lisäinformaattsia.)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'koko istori',
'namespacesall' => 'kõik',
'monthsall' => 'kõik',
'limitall' => 'kõik',

# action=purge
'confirm_purge_button' => 'OK',

# action=watch/unwatch
'confirm-watch-button' => 'OK',
'confirm-unwatch-button' => 'OK',

# Table pager
'table_pager_first' => 'Esimein cülci',
'table_pager_last' => 'Viimein cülci',
'table_pager_limit_submit' => 'Mee',

# Watchlist editing tools
'watchlisttools-view' => 'Näüt muutuhsõd',
'watchlisttools-edit' => 'Muuttaa spiiskaa',
'watchlisttools-raw' => 'Muut lähtefaili',

# Core parser functions
'duplicate-defaultsort' => '\'\'\'Warning:\'\'\' Default sort key "$2" overrides earlier default sort key "$1".',

# Special:FileDuplicateSearch
'fileduplicatesearch-filename' => 'Failinimi:',
'fileduplicatesearch-submit' => 'Etsi',

# Special:SpecialPages
'specialpages' => 'Osoobenoid cüľľed',

# External image whitelist
'external_image_whitelist' => '# Jättägä kase rivi mokomassi, minenä-mokomana se on õõmaz.<pre>
# Sijottaga tänne säännollizije ilmaud’d’e fragmentad (se õsa, kumpa on // väliz)
# ned leevät võrrõttu ulko-kuvije URL-sõ.
# Sopivad leeväd näütettü kuvijna, muud leeväd näütettü kuvijsõ viitauina.
# Rivid, kummad alguta //-ss, pietä kommentaarijina. Rivid eväd õlla tunnuttu registra suhtõsõ.
# Sijottaga säännollizije ilmaud’d’e fragmentad kaze rivi ülez.

# Jättägä kase rivi mokomassi, minenä-mokomana se on õõmaz.',

# Special:Tags
'tag-filter' => "[[Special:Tags|Deskriptorije]] fil'tra:",
'tags-edit' => 'muuttaa',

# HTML forms
'htmlform-selectorother-other' => 'Muu',

# New logging system
'rightsnone' => '(eb õõ)',

# Feedback
'feedback-message' => 'Ilmottamin:',
'feedback-cancel' => 'Otmeńoit',
'feedback-close' => 'On tehtü',

);
